@@ -9,22 +9,11 @@ test_that("hexagonal logo works", {
 
 test_that("parallel benchmark works", {
   # Define toy function that sleeps for (60/cpus) seconds
-  a <- function(cpus) {Sys.sleep(4/cpus)}
-  times_df <- par_benchmark(c(1, 2, 4), a, quiet = TRUE)
-  expect_equal(length(times_df$times), 3)
-  expect_output(par_benchmark(c(4), a, quiet = FALSE))
-  expect_output(par_benchmark(c(4), a, quiet = FALSE, plot = TRUE))
-  # print(list.files("."))
-  # is.windows <- Sys.info()['sysname'] == "Windows"
-  # # print(paste0("Is windows ", is.windows))
-  # print(paste0("OS: ", Sys.info()['sysname']))
-  # if (!is.windows) {
-  #   expect_true(file.exists("./Rplots.pdf"))
-  #   expect_false(dir.exists("./Rplots.pdf"))
-  #   expect_gt(file.size("Rplots.pdf"), 0)
-  # }
-  # file.remove("./Rplots.pdf")
-  # expect_false(file.exists("./Rplots.pdf"))
+  a <- function(cpus) {Sys.sleep(2/cpus)}
+  times_df <- par_benchmark(c(1, 2), a, quiet = TRUE)
+  expect_equal(length(times_df$times), 2)
+  expect_output(par_benchmark(c(2), a, quiet = FALSE))
+  expect_output(par_benchmark(c(2), a, quiet = FALSE, plot = TRUE))
 })
 
 test_that("combine with progress bar works", {
@@ -37,4 +26,4 @@ test_that("combine with progress bar works", {
                             i
                           }
   expect_equal(c(unname(out)), 1:N)
-})
+})
\ No newline at end of file
